package Sah::Schemas::WordList;

our $DATE = '2021-06-07'; # DATE
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Sah schemas related to WordList

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::WordList - Sah schemas related to WordList

=head1 VERSION

This document describes version 0.003 of Sah::Schemas::WordList (from Perl distribution Sah-Schemas-WordList), released on 2021-06-07.

=head1 CONTRIBUTOR

=for stopwords perlancar (on netbook-dell-xps13)

perlancar (on netbook-dell-xps13) <perlancar@gmail.com>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-WordList>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-WordList>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-WordList>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah> - specification

L<Data::Sah>

L<WordList>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
